summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls/TInlineFrame.php
diff options
context:
space:
mode:
Diffstat (limited to 'framework/Web/UI/WebControls/TInlineFrame.php')
-rw-r--r--framework/Web/UI/WebControls/TInlineFrame.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/framework/Web/UI/WebControls/TInlineFrame.php b/framework/Web/UI/WebControls/TInlineFrame.php
index ba590c06..b299678b 100644
--- a/framework/Web/UI/WebControls/TInlineFrame.php
+++ b/framework/Web/UI/WebControls/TInlineFrame.php
@@ -11,6 +11,7 @@
*/
namespace Prado\Web\UI\WebControls;
+use Prado\TPropertyValue;
/**
* TInlineFrame class
@@ -31,7 +32,7 @@ namespace Prado\Web\UI\WebControls;
* @package Prado\Web\UI\WebControls
* @since 3.0
*/
-class TInlineFrame extends TWebControl implements IDataRenderer
+class TInlineFrame extends \Prado\Web\UI\WebControls\TWebControl implements \Prado\IDataRenderer
{
/**
* @return string tag name of the iframe.
@@ -107,7 +108,7 @@ class TInlineFrame extends TWebControl implements IDataRenderer
/**
* Returns the URL that this iframe will load content from
* This method is required by {@link IDataRenderer}.
* It is the same as {@link getFrameUrl()}.
* @return string the URL that this iframe will load content from
* @see getFrameUrl
@@ -120,7 +121,7 @@ class TInlineFrame extends TWebControl implements IDataRenderer
/**
* Sets the URL that this iframe will load content from.
* This method is required by {@link IDataRenderer}.
* It is the same as {@link setFrameUrl()}.
* @param string the URL that this iframe will load content from
* @see setFrameUrl
@@ -107,7 +108,7 @@ class TInlineFrame extends TWebControl implements IDataRenderer
/**
* Returns the URL that this iframe will load content from
- * This method is required by {@link IDataRenderer}.
+ * This method is required by {@link \Prado\IDataRenderer}.
* It is the same as {@link getFrameUrl()}.
* @return string the URL that this iframe will load content from
@@ -120,7 +121,7 @@ class TInlineFrame extends TWebControl implements IDataRenderer
/**
* Sets the URL that this iframe will load content from.
- * This method is required by {@link IDataRenderer}.
+ * This method is required by {@link \Prado\IDataRenderer}.
* It is the same as {@link setFrameUrl()}.
* @param string the URL that this iframe will load content from